@@ -71,11 +71,7 @@ class DRequests():
         return self._server_ip
     
     def get_ip(self):
-        import socket
-        try:
-            ip = socket.gethostbyname(get_subdomain(self.url))
-        except:
-            ip = ''
+        ip = self.c.getinfo(pycurl2.PRIMARY_IP)
         return ip
     
     @property
